@@ -28,6 +28,7 @@ pub enum MessageType {
     Reply = 19,
     ApplicationCommand = 20,
     GuildInviteReminder = 22,
+    ContextMenuCommand = 23,
 }
 
 impl TryFrom<u8> for MessageType {
@@ -55,6 +56,7 @@ impl TryFrom<u8> for MessageType {
             19 => MessageType::Reply,
             20 => MessageType::ApplicationCommand,
             22 => MessageType::GuildInviteReminder,
+            23 => MessageType::ContextMenuCommand,
             _ => return Err(ConversionError::MessageType(value)),
         };
 
@@ -96,6 +98,7 @@ mod tests {
         serde_test::assert_tokens(&MessageType::Reply, &[Token::U8(19)]);
         serde_test::assert_tokens(&MessageType::ApplicationCommand, &[Token::U8(20)]);
         serde_test::assert_tokens(&MessageType::GuildInviteReminder, &[Token::U8(22)]);
+        serde_test::assert_tokens(&MessageType::ContextMenuCommand, &[Token::U8(23)]);
     }
 
     #[test]
@@ -168,6 +171,10 @@ mod tests {
             MessageType::try_from(22).unwrap(),
             MessageType::GuildInviteReminder
         );
+        assert_eq!(
+            MessageType::try_from(23).unwrap(),
+            MessageType::ContextMenuCommand
+        );
         assert_eq!(
             MessageType::try_from(250).unwrap_err(),
             ConversionError::MessageType(250)
