@@ -89,8 +89,10 @@ mod tests {
                 joined_at: None,
                 mute: true,
                 nick: Some("bar".to_owned()),
+                permissions: None,
                 premium_since: None,
                 roles: Vec::new(),
+                user: None,
             }),
             name: "foo".to_owned(),
             public_flags: UserFlags::empty(),
@@ -116,7 +118,7 @@ mod tests {
                 Token::Some,
                 Token::Struct {
                     name: "PartialMember",
-                    len: 5,
+                    len: 7,
                 },
                 Token::Str("deaf"),
                 Token::Bool(false),
@@ -127,9 +129,13 @@ mod tests {
                 Token::Str("nick"),
                 Token::Some,
                 Token::Str("bar"),
+                Token::Str("permissions"),
+                Token::None,
                 Token::Str("roles"),
                 Token::Seq { len: Some(0) },
                 Token::SeqEnd,
+                Token::Str("user"),
+                Token::None,
                 Token::StructEnd,
                 Token::Str("username"),
                 Token::Str("foo"),
