@@ -136,7 +136,9 @@ mod tests {
             sort_value: Some(1),
             tags: "foo,bar,baz".into(),
             user: Some(User {
+                accent_color: None,
                 avatar: Some("aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa".to_owned()),
+                banner: None,
                 bot: false,
                 discriminator: "0001".to_owned(),
                 email: Some("address@example.com".to_owned()),
@@ -189,11 +191,15 @@ mod tests {
                 Token::Some,
                 Token::Struct {
                     name: "User",
-                    len: 13,
+                    len: 15,
                 },
+                Token::Str("accent_color"),
+                Token::None,
                 Token::Str("avatar"),
                 Token::Some,
                 Token::Str("aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa"),
+                Token::Str("banner"),
+                Token::None,
                 Token::Str("bot"),
                 Token::Bool(false),
                 Token::Str("discriminator"),
