@@ -69,7 +69,9 @@ mod tests {
             synced_at: Some("timestamp".to_owned()),
             syncing: Some(false),
             user: Some(User {
+                accent_color: None,
                 avatar: Some("hash".to_owned()),
+                banner: None,
                 bot: true,
                 discriminator: "1000".to_owned(),
                 email: None,
@@ -142,11 +144,15 @@ mod tests {
                 Token::Some,
                 Token::Struct {
                     name: "User",
-                    len: 5,
+                    len: 7,
                 },
+                Token::Str("accent_color"),
+                Token::None,
                 Token::Str("avatar"),
                 Token::Some,
                 Token::Str("hash"),
+                Token::Str("banner"),
+                Token::None,
                 Token::Str("bot"),
                 Token::Bool(true),
                 Token::Str("discriminator"),
@@ -192,7 +198,9 @@ mod tests {
             synced_at: Some("timestamp".to_owned()),
             syncing: Some(false),
             user: Some(User {
+                accent_color: None,
                 avatar: Some("hash".to_owned()),
+                banner: None,
                 bot: true,
                 discriminator: "1000".to_owned(),
                 email: None,
@@ -285,11 +293,15 @@ mod tests {
                 Token::Some,
                 Token::Struct {
                     name: "User",
-                    len: 5,
+                    len: 7,
                 },
+                Token::Str("accent_color"),
+                Token::None,
                 Token::Str("avatar"),
                 Token::Some,
                 Token::Str("hash"),
+                Token::Str("banner"),
+                Token::None,
                 Token::Str("bot"),
                 Token::Bool(true),
                 Token::Str("discriminator"),
