@@ -29,9 +29,6 @@ pub struct PartialGuild {
     pub member_count: Option<u64>,
     pub mfa_level: MfaLevel,
     pub name: String,
-    #[deprecated(since = "0.4.3", note = "no longer provided by discord, see #839")]
-    #[serde(skip)]
-    pub nsfw: bool,
     pub nsfw_level: NSFWLevel,
     pub owner_id: UserId,
     #[serde(skip_serializing_if = "Option::is_none")]
@@ -42,8 +39,6 @@ pub struct PartialGuild {
     #[serde(skip_serializing_if = "Option::is_none")]
     pub premium_subscription_count: Option<u64>,
     pub premium_tier: PremiumTier,
-    #[deprecated(since = "0.4.3", note = "no longer provided by discord, see #884")]
-    pub region: String,
     pub roles: Vec<Role>,
     pub rules_channel_id: Option<ChannelId>,
     pub splash: Option<String>,
@@ -67,10 +62,8 @@ mod tests {
     use serde_test::Token;
 
     #[allow(clippy::too_many_lines)]
-    #[allow(deprecated)]
     #[test]
     fn test_partial_guild() {
-        #[allow(deprecated)]
         let value = PartialGuild {
             id: GuildId(1),
             afk_channel_id: Some(ChannelId(2)),
@@ -89,7 +82,6 @@ mod tests {
             member_count: Some(12_000),
             mfa_level: MfaLevel::Elevated,
             name: "the name".to_owned(),
-            nsfw: false,
             nsfw_level: NSFWLevel::Default,
             owner_id: UserId(5),
             owner: Some(false),
@@ -97,7 +89,6 @@ mod tests {
             preferred_locale: "en-us".to_owned(),
             premium_subscription_count: Some(3),
             premium_tier: PremiumTier::Tier1,
-            region: "us-west".to_owned(),
             roles: Vec::new(),
             rules_channel_id: Some(ChannelId(6)),
             splash: Some("splash hash".to_owned()),
@@ -114,7 +105,7 @@ mod tests {
             &[
                 Token::Struct {
                     name: "PartialGuild",
-                    len: 34,
+                    len: 33,
                 },
                 Token::Str("id"),
                 Token::NewtypeStruct { name: "GuildId" },
@@ -185,8 +176,6 @@ mod tests {
                 Token::U64(3),
                 Token::Str("premium_tier"),
                 Token::U8(1),
-                Token::Str("region"),
-                Token::Str("us-west"),
                 Token::Str("roles"),
                 Token::Seq { len: Some(0) },
                 Token::SeqEnd,
