@@ -174,7 +174,9 @@ mod tests {
             }),
             expires_at: Some("expires at timestamp".to_owned()),
             inviter: Some(User {
+                accent_color: None,
                 avatar: None,
+                banner: None,
                 bot: false,
                 discriminator: "0001".to_owned(),
                 email: None,
@@ -197,7 +199,9 @@ mod tests {
                     premium_since: None,
                     roles: Vec::new(),
                     user: User {
+                        accent_color: None,
                         avatar: None,
+                        banner: None,
                         bot: false,
                         discriminator: "0001".to_owned(),
                         email: None,
@@ -218,7 +222,9 @@ mod tests {
             }),
             target_type: Some(TargetType::Stream),
             target_user: Some(User {
+                accent_color: None,
                 avatar: None,
+                banner: None,
                 bot: false,
                 discriminator: "0001".to_owned(),
                 email: None,
@@ -345,10 +351,14 @@ mod tests {
                 Token::Some,
                 Token::Struct {
                     name: "User",
-                    len: 5,
+                    len: 7,
                 },
+                Token::Str("accent_color"),
+                Token::None,
                 Token::Str("avatar"),
                 Token::None,
+                Token::Str("banner"),
+                Token::None,
                 Token::Str("bot"),
                 Token::Bool(false),
                 Token::Str("discriminator"),
@@ -376,10 +386,14 @@ mod tests {
                 Token::Str("user"),
                 Token::Struct {
                     name: "User",
-                    len: 5,
+                    len: 7,
                 },
+                Token::Str("accent_color"),
+                Token::None,
                 Token::Str("avatar"),
                 Token::None,
+                Token::Str("banner"),
+                Token::None,
                 Token::Str("bot"),
                 Token::Bool(false),
                 Token::Str("discriminator"),
@@ -406,10 +420,14 @@ mod tests {
                 Token::Some,
                 Token::Struct {
                     name: "User",
-                    len: 5,
+                    len: 7,
                 },
+                Token::Str("accent_color"),
+                Token::None,
                 Token::Str("avatar"),
                 Token::None,
+                Token::Str("banner"),
+                Token::None,
                 Token::Str("bot"),
                 Token::Bool(false),
                 Token::Str("discriminator"),
