@@ -52,7 +52,9 @@ mod tests {
     "code": "code",
     "created_at": "2021-04-07T14:55:37+00:00",
     "creator": {
+        "accent_color": null,
         "avatar": "avatar",
+        "banner": "06c16474723fe537c283b8efa61a30c8",
         "discriminator": "1111",
         "id": "100",
         "public_flags": 0,
@@ -169,7 +171,9 @@ mod tests {
             code: "code".into(),
             created_at: "2021-04-07T14:55:37+00:00".into(),
             creator: User {
+                accent_color: None,
                 avatar: Some("avatar".into()),
+                banner: Some("06c16474723fe537c283b8efa61a30c8".to_owned()),
                 bot: false,
                 email: None,
                 discriminator: "1111".into(),
@@ -325,11 +329,16 @@ mod tests {
                 Token::Str("creator"),
                 Token::Struct {
                     name: "User",
-                    len: 6,
+                    len: 8,
                 },
+                Token::Str("accent_color"),
+                Token::None,
                 Token::Str("avatar"),
                 Token::Some,
                 Token::Str("avatar"),
+                Token::Str("banner"),
+                Token::Some,
+                Token::Str("06c16474723fe537c283b8efa61a30c8"),
                 Token::Str("bot"),
                 Token::Bool(false),
                 Token::Str("discriminator"),
